# GSHAPA: Gene Set Analysis for Single-Cell RNA-seq Using Random Forest and SHAP Values

<div style="display: flex; justify-content: center;">
 <img src="logo.webp" height="250">
</div>

This Python package Gene Set Analysis for Single-Cell RNA-seq Using Random Forest and SHAP Values

### Installation:

`pip install gshapa`

### Documentation:

[gshapa.readthedocs.io](gshapa.readthedocs.io)

### GitLab repository
[gitlab repository and tutorials](https://gitlab.com/bf2i/gshapa)

### Tutorials:

Check the jupyter notebook tutorials located in the __tutorial__ folder
+ `simulator.ipynb` for the assessment of the method on synthetic data
+ `MS-dataset-RF-1percent.ipynb`, `DN-RF-1percent.ipynb`, `DII-RF-1percent.ipynb`, `COVID-RF-1percent.ipynb` and `AD-RF-1percent.ipynb` for different bio-medical applications

### Authors:

For bug reports and feedback do not hesitate to contact the authors

+ Sergio Peignier: sergio.peignier AT insa-lyon.fr
+ Sara Khademioureh: khademio AT ualberta.ca

### Maintainer:

+ Sergio Peignier: sergio.peignier AT insa-lyon.fr